glados.core module — GLaDOS 0.0.1-alpha1 documentation

# glados.core module

class `glados.core.` `Glados`

  Bases: `object`

  Glados is the core of the GLaDOS package.

  `add_bot`(bot)

    Add a new bot to GLaDOS.

    Parameters

      bot (GladosBot) – the bot to be added to GLaDOS

  `add_plugin`(plugin)

    Add a plugin to GLaDOS

    Parameters

      plugin (GladosPlugin) – the plugin to be added to GLaDOS

  `request`(request)

    Send a request to GLaDOS.

    Parameters

      request (GladosRequest) – the request to be sent to GLaDOS